FlanaBot
========

|license| |project_version| |python_version|

Bot based on `github.com/AlberLC/multibot`_ to manage Discord, Telegram and Twitch chats, moderate them and add functionalities.

|

Installation
------------

Python 3.10 or higher is required.

.. code-block::

    pip install flanabot

|

Features
--------

- Talks to users.
- Delete message batches.
- It works both in groups and in private chats.
- Understands numbers and amounts of time textually expressed (useful for deleting a message batch or saying "flanabot ban john for one hour and 20 minutes").
- Shows interactive via buttons charts of past, current and forecast weather.
- Change user roles temporarily or forever.
- Mute users temporarily or forever.
- Ban users temporarily or forever.
- Configurable default behavior for each chat, just talk to him to configure it.
- Get media from Instagram, Reddit, TikTok, Twitter, YouTube and others and send it to the chat. From TikTok also obtains data about the song that is playing in the video.


.. |license| image:: https://img.shields.io/github/license/AlberLC/flanabot?style=flat
    :target: https://github.com/AlberLC/flanabot/blob/main/LICENSE
    :alt: License

.. |project_version| image:: https://img.shields.io/pypi/v/flanabot
    :target: https://pypi.org/project/flanabot/
    :alt: PyPI

.. |python_version| image:: https://img.shields.io/pypi/pyversions/flanabot
    :target: https://www.python.org/downloads/
    :alt: PyPI - Python Version

.. _github.com/AlberLC/multibot: https://github.com/AlberLC/multibot
